@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: settings.py 11517 2019-05-03 12:53:40Z Andy $
+# $Id: settings.py 12425 2020-07-26 06:31:20Z Bear $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-05-03 21:53:40 +0900 (週五, 03 五月 2019) $
-# $Revision: 11517 $
+# $Author: Bear $
+# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
+# $Revision: 12425 $
 
 import os
 import sys
@@ -35,7 +35,7 @@ import Iuno
 # Project settings.
 
 APP_NAME = 'mailworker'
-APP_VERSION = "0.3.0." + "$Revision: 11517 $"[11:-2]
+APP_VERSION = "0.4.1." + "$Revision: 12425 $"[11:-2]
  
 INSTALLED_APPS = (
     'django.contrib.auth',
@@ -112,6 +112,11 @@ IUNO_CLOUD_LOGGING_FILE = os.path.join(os.path.dirname(__file__), 'mail.log')
 #============================================================================
 ALLOWED_DOMAINS = ['extension.mail', ]
 
+IUNO_SITE_DOMAIN_NAMES = {
+    DEVELOPMENT: '', 
+    STAGE: '', 
+    PRODUCTION: ''
+}
 
 BASE_DIR = os.path.dirname(os.path.dirname(__file__))
 DATABASES = {
