@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11517 2019-05-03 12:53:40Z Andy $
+# $Id: urls.py 12425 2020-07-26 06:31:20Z Bear $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-05-03 20:53:40 +0800 (週五, 03 五月 2019) $
-# $Revision: 11517 $
+# $Author: Bear $
+# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
+# $Revision: 12425 $
 
 from django.conf.urls import include, url
 # Required import for 404 handle.
@@ -36,7 +36,6 @@ Iuno.attachURLs(settings, urlpatterns)
 
 urlpatterns += patterns('',
     (r'^i18n/', include('Iuppiter.i18n.urls')),
-    (r'^admin/', include(admin.site.urls)),
+    (r'^admin/', admin.site.urls),
 )
 
-
