@@ -24,6 +24,7 @@ import sys
 import pkg_resources
 import subprocess
 import psutil
+import hashlib
 
 import requests
 
@@ -142,8 +143,8 @@ ERROR [%ss]: %s (%s)
                 ''' % (time, name, classname)
                 logger.info(msg)
                 for error in testcase.get('error', []):
-                    logger.info("Message: ", error.get("message", None))
-                    logger.info("Type: ", error.get("type", None))
+                    logger.info("Message: %s" % error.get("message", None))
+                    logger.info("Type: %s" % error.get("type", None))
                     logger.info(error.get("traceback", None))
                     errorCount += 1
         
